package com.company.util;

import org.kie.api.runtime.KieSession;
import org.kie.api.runtime.manager.RuntimeEngine;
import org.kie.api.runtime.manager.RuntimeManager;
import org.kie.api.runtime.manager.audit.AuditService;
import org.kie.api.task.TaskService;

public class RuntimeEngineImplDecorator {
    private RuntimeEngine runtimeEngine;
    private RuntimeManager runtimeManager;

    public RuntimeEngineImplDecorator(RuntimeManager runtimeManager, RuntimeEngine runtimeEngine) {
        this.runtimeManager = runtimeManager;
        this.runtimeEngine = runtimeEngine;
    }

    public RuntimeManager getRuntimeManager() {
        return runtimeManager;
    }

    public RuntimeEngine getRuntimeEngine() {
        return runtimeEngine;
    }

    /**
     * Returns <code>KieSession</code> configured for this <code>RuntimeEngine</code>
     * 
     * @return
     */
    KieSession getKieSession() {
        return runtimeEngine.getKieSession();
    }

    /**
     * Returns <code>TaskService</code> configured for this <code>RuntimeEngine</code>
     * 
     * @return
     */
    TaskService getTaskService() {
        return runtimeEngine.getTaskService();
    }

    /**
     * Returns <code>AuditService</code> that gives access to underlying runtime data such as process instance, node
     * instance and variable log entries.
     * 
     * @return
     */
    AuditService getAuditLogService() {
        return runtimeEngine.getAuditLogService();
    }
}
